<?php
/*
Plugin Name: Readtime Shortcode (YouTube duration)
Description: A shortcode to display the total duration of YouTube videos on a page.
Version: 1.1
Author: EasyToolsWP.com
*/

// Function to get YouTube video duration using YouTube Data API
function get_youtube_video_duration($video_id, $api_key) {
    $api_url = 'https://www.googleapis.com/youtube/v3/videos?part=contentDetails&id=' . $video_id . '&key=' . $api_key;
    $response = wp_remote_get($api_url);
    if (is_wp_error($response)) {
        return false;
    }
    $data = json_decode(wp_remote_retrieve_body($response), true);
    if (!empty($data['items'])) {
        return $data['items'][0]['contentDetails']['duration'];
    }
    return false;
}

// Function to convert YouTube duration (ISO 8601) to seconds
function convert_youtube_duration_to_seconds($youtube_duration) {
    preg_match_all('/(\d+)/', $youtube_duration, $parts);

    $units = array('H' => 3600, 'M' => 60, 'S' => 1);
    $time_in_seconds = 0;
    foreach ($parts[0] as $index => $part) {
        $unit = substr($youtube_duration, strpos($youtube_duration, $part) + strlen($part), 1);
        $time_in_seconds += intval($part) * $units[$unit];
    }
    return $time_in_seconds;
}

// Shortcode function to display total YouTube video duration
function youtube_video_duration_shortcode($atts) {
    $atts = shortcode_atts(
        array(
            'api_key' => '',
        ),
        $atts,
        'youtube_video_duration'
    );

    if (empty($atts['api_key'])) {
        return 'YouTube API key is required.';
    }

    $content = get_post_field('post_content', get_the_ID());

    preg_match_all('/https:\/\/www\.youtube\.com\/watch\?v=([a-zA-Z0-9_-]+)/i', $content, $matches);
    $video_ids = array_unique($matches[1]);

    $total_duration = 0;

    foreach ($video_ids as $video_id) {
        $duration = get_youtube_video_duration($video_id, $atts['api_key']);
        if ($duration) {
            $total_duration += convert_youtube_duration_to_seconds($duration);
        }
    }

    $hours = floor($total_duration / 3600);
    $minutes = floor(($total_duration % 3600) / 60);
    $seconds = $total_duration % 60;

    $formatted_duration = '';
    
    if ($hours > 0) {
        $formatted_duration .= sprintf('%d %s ', $hours, _n('hour', 'hours', $hours, 'readtime-shortcode'));
    }

    if ($minutes > 0) {
        $formatted_duration .= sprintf('%d %s', $minutes, _n('minute', 'minutes', $minutes, 'readtime-shortcode'));
    }

    if (empty($formatted_duration)) {
        $formatted_duration = '0 minutes';
    }

    return 'Videoes got a total duration of ' . $formatted_duration;
}
add_shortcode('youtube_video_duration', 'youtube_video_duration_shortcode');
